@@ -1,6 +1,6 @@
 package Log::Shiras::Report;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.46.0");
+use version; our $VERSION = version->declare("v0.48.0");
 use strict;
 use warnings;
 use 5.010;
@@ -51,7 +51,7 @@ around add_line => sub{
 		# Check for a manage_message add on
 		if( $self->can( 'manage_message' ) ){
 			$message_ref = $self->manage_message( $message_ref );
-			###InternalReporT	$switchboard->master_talk( { report => 'log_file', level => 3,
+			###InternalReporT	$switchboard->master_talk( { report => 'log_file', level => 1,
 			###InternalReporT		name_space => 'Log::Shiras::Report::CSVFile::add_line',
 			###InternalReporT		message =>[ 'Updated the message to:', $message_ref->{message} ], } );
 		}
@@ -64,6 +64,8 @@ around add_line => sub{
 		return $times;
 	};
 	
+sub _my_test_for_around_add_line{ 1 };
+	
 
 #########1 Phinish            3#########4#########5#########6#########7#########8#########9
 
